function zigR = izvuci(Dr, D, alpha)

% zigR = izvuci(Dr, D, alpha) - izvlaci zig iz matrice Dr uz koeficijent
% alpha
% Dr - odabrana matrica (oznaceni detalji wavelet transformacije)
% D - odabrana matrica (originalni, neoznacani detalji wavelet transformacije)
% alpha - jacina oznacavanja

Wbr = 1; %brojac za W


Dsize = size (D);
a=1;
b=1;
for i=5:Dsize(1)-5
   for j=5:Dsize(2)-5
     izvuceni_koef = real(Dr(i,j));
     orig_koef = D(i,j);
     if abs(orig_koef) > 20
      %   koef(a, b) = izvuceni_koef;
      %   koef(a, b+1) = orig_koef;
      %   a=a+1;b=b+1;
         %watermark[w++] = (input_coeff - orig_coeff) / (alpha * pow(fabs(orig_coeff), 1.0 / 1.2));
         W(Wbr, 1) = (izvuceni_koef - orig_koef) / (alpha * ((abs(orig_koef))^(1.0 / 1.2)));
         Wbr = Wbr + 1;         
     end
 end
end
Wsize = size(W);
nula(1,1) = Wsize(1);

zigR = nadovezi(nula,W);
